#!/bin/bash

function redirect-output {
    if ${LOCAL_CI}; then
	# If local CI don't output logs. Let the developer check them.
	exec 3>&1 4>&2 >/dev/null
    fi
}

function restore-output {
    if ${LOCAL_CI}; then
	# Restore stdout and stderr
	exec 1>&3 2>&4 3>&- 4>&-
    fi
}

function log-header {
    set +x
    header=$1
    print-with-red "##### START ${header} ######"
}

function log-footer {
    footer=$1
    print-with-red "##### END ${footer} ######"
}

function wait-logs {
    log-header "wait for pods logs"
    cat /tmp/wait-for-pods-log
    log-footer "wait for pods logs"
}

function pod-logs {
    log-header "pod logs"
    oc get pods --all-namespaces
    wait-logs
    log-footer "pod logs"
}

function secret-logs {
    log-header "secrets logs"
    oc get secrets --all-namespaces | grep mediawiki-postgresql-binding
    oc get secrets mediawiki-postgresql-binding -o yaml -n default
    log-footer "secrets logs"
}

function broker-logs {
    log-header "broker logs"
    oc logs $(oc get pods -o name -l service=asb --all-namespaces | cut -f 2 -d '/') -c asb -n ansible-service-broker
    log-footer "broker logs"
}

function catalog-logs {
    log-header "catlog logs"
    oc get clusterserviceclasses --all-namespaces
    oc get serviceinstances --all-namespaces
    oc logs $(oc get pods -o name -l app=controller-manager --all-namespaces | cut -f 2 -d '/') -n kube-service-catalog
    log-footer "catlog logs"
}

function print-all-logs {
    secret-logs
    wait-logs
    broker-logs
    catalog-logs
}
